import React, { useEffect, useRef, useState } from "react";

import { useDispatch } from "react-redux";
import { getGeocode, getInfoByCoords } from "@/api/mapService";

import { useModel } from "umi";
import { APILoader, Provider, Map, Marker } from "@uiw/react-amap";
import { Card, NavBar, Input, Uploader, Search, Button } from "react-vant";
import styles from "./locationSearch.less";

const LocationSearch = () => {
  const [inputStr, setInputStr] = useState("");
  const [curLocation, setCurLocation] = useState<AMap.LngLat>();
  const { setMatterAddress, matterAddress } = useModel("global");
  const [locationInfo, setLocationInfo] = useState<Record<string, any>>();

  const [isReady, setIsReady] = useState(false);
  const mapRef = useRef<{ map: AMap.Map }>(null);

  const [searchList, setSearchList] = useState<
    {
      name: string;
      address: string;
      location: string;
    }[]
  >();

  /**
   * 获取当前位置
   */
  const getLocation = (): Promise<AMap.LngLat> => {
    return new Promise((resolve, reject) => {
      AMap.plugin(["AMap.Geolocation"], function () {
        var geolocation = new AMap.Geolocation({
          // 是否使用高精度定位，默认：true
          enableHighAccuracy: true,
          // 设置定位超时时间，默认：无穷大
          timeout: 10000,
          // 定位按钮的停靠位置的偏移量，默认：Pixel(10, 20)
          buttonOffset: new AMap.Pixel(10, 20),
          //  定位成功后调整地图视野范围使定位位置及精度范围视野内可见，默认：false
          zoomToAccuracy: true,
          //  定位按钮的排放位置,  RB表示右下
          buttonPosition: "RB",
        });
        function onComplete(data: AMap.GeolocationResult) {
          // data是具体的定位信息
          if (data) {
            const location = data.position;
            resolve(location);
          } else {
            reject();
          }
        }
        function onError(error: any) {
          reject(
            `getPosError:${error.code},${navigator.geolocation},${error.message}`
          );
        }

        geolocation.getCurrentPosition((status, result) => {
          console.log(status, result);
          if (status === "complete") {
            onComplete(result);
          }
          if (status === "error") {
            onError(result);
          }
        });
      });
    });
  };

  useEffect(() => {
    if (isReady) {
      /* 定位 */
      getLocation().then((location: AMap.LngLat) => {
        setCurLocation(location);
        console.log(mapRef.current?.map);
      });
    }
  }, [isReady]);

  const getSearchList = (value: string) => {
    if (value && value.length > 0) {
      getInfoByCoords(value, locationInfo?.addressComponent?.city).then(
        (res) => {
          if (res?.pois && res.pois.length > 0) {
            setSearchList(res.pois);
          }
        }
      );
    }
  };

  useEffect(() => {
    if (curLocation) {
      mapRef.current?.map.setZoomAndCenter(18, curLocation, false);
      getGeocode([curLocation.lng, curLocation.lat] as any).then((res) => {
        setLocationInfo(res.data);
      });
    }
  }, [curLocation]);

  const onSelect = (params: any) => {
    setInputStr(params.address);
    const location = params.location as string;
    const position = location.split(",");

    setCurLocation(new AMap.LngLat(Number(position[0]), Number(position[1])));
    setSearchList([]);
  };
  const onClickRight = () => {
    if (!locationInfo && !curLocation) {
      alert("当前无定位，请等待定位完成！");
      return;
    }
    setMatterAddress({ ...locationInfo, location: curLocation });
    history.back();
  };
  return (
    <div className={styles.container}>
      {/* <NavBar
        title="问题地点"
        onClickLeft={() => history.back()}
        leftText="返回"
        rightText="确认"
        onClickRight={onClickRight}
      /> */}
      <div className={styles.searchView}>
        <div>
          <Search
            value={inputStr}
            onChange={(value) => {
              setInputStr(value);
              getSearchList(value);
            }}
            clearable
            placeholder="请输入搜索关键词"
          />
        </div>
        <div>
          {searchList?.map((v) => {
            return (
              <div className={styles.Item} onClick={() => onSelect(v)}>
                {v.address}
              </div>
            );
          })}
        </div>
      </div>
      <div className={styles.mapView}>
        <APILoader
          akey="0e6112b0f59f96b982256402adcb0fe3"
          version="2.0"
          Loca={{ version: "2.0.0" }}
        >
          <Provider>
            <Map
              viewMode="2D"
              zooms={[0, 20]}
              onComplete={() => {
                setIsReady(true);
              }}
              ref={mapRef}
              onClick={(e) => {
                setCurLocation(e.lnglat);
              }}
            >
              <>{isReady && <Marker visiable position={curLocation} />}</>
            </Map>
          </Provider>
        </APILoader>
      </div>
      <div className={styles.location_container}>
        <Card>
          <Card.Header>
            当前位置: {locationInfo?.addressComponent?.city}
          </Card.Header>
          <Card.Body>{locationInfo?.addres ?? "暂无"}</Card.Body>
          <Button
            type="primary"
            block
            round
            style={{ marginTop: 16 }}
            onClick={onClickRight}
          >
            确认
          </Button>
        </Card>
      </div>
    </div>
  );
};

export default LocationSearch;
