import React, { useState } from "react";
import styles from "./report.less";

import {
  Card,
  NavBar,
  Popup,
  Input,
  Picker,
  Uploader,
  Button,
  UploaderValueItem,
  Notify,
} from "react-vant";
import { history, useModel } from "umi";
import { submitForm, uploadFile } from "@/api";
/**
 * 上报页
 * @returns
 */
const Report = () => {
  const {
    matterAddress,
    setMatterAddress,
    loginInfo,
    user,
    area,
    setArea,
    problemDesc,
    setProblemDesc,
    fileList,
    setFileList,
  } = useModel("global");
  const [areaVisible, setAreaVisible] = React.useState(false);

  const [loading, setLoading] = React.useState(false);

  const columns = [
    { text: "广安市城南", value: 511600 },
    { text: "广安市城北", value: 511602 },
    { text: "前锋区", value: 511603 },
    { text: "岳池县", value: 511621 },
    { text: "武胜县", value: 511622 },
    { text: "邻水县", value: 511623 },
    { text: "华蓥市", value: 511681 },
    { text: "经开区", value: 511682 },
  ];

  const findName = (id: number) => {
    return columns.find((v) => v.value == id)?.text;
  };

  const handleSubmit = async () => {
    /** 校验 */
    if (problemDesc.length === 0) {
      Notify.show({ type: "warning", message: "请您描述您的问题" });
      return;
    }
    if (fileList.length === 0) {
      Notify.show({ type: "warning", message: "请您上传问题图片" });
      return;
    }
    if (area === 0) {
      Notify.show({ type: "warning", message: "请您选择所属地区" });
      return;
    }

    if (!user) {
      Notify.show({ type: "warning", message: "请您先获得权限认证" });
      return;
    }

    if (!matterAddress?.addres || matterAddress?.addres === 0) {
      Notify.show({ type: "warning", message: "请您选择事发位置" });
      return;
    }
    setLoading(true);

    try {
      const uploadReq = fileList.map((v) => {
        const formData = new FormData();

        formData.append("file", v.file as File);

        return uploadFile(formData);
      });

      if (!user) {
      }

      const imgList = (await Promise.all(uploadReq)).map((v) => v.data);

      const form = {
        address: matterAddress.addres,
        telphone: user.mobile,
        problemDesc: problemDesc,
        reporter: user.nickName,
        longitude: matterAddress.location.lng,
        latitude: matterAddress.location.lat,
        belongArea: area,
        belongAreaName: findName(area) as string,
        fileNames: imgList.map((v) => v.name).join(","),
        filePaths: imgList.map((v) => v.path).join(","),
      };

      submitForm(form).then((res) => {
        if (res.code === 200) {
          Notify.show({ type: "success", message: "上报成功！" });
          setLoading(false);
        }
      });
    } catch (error) {
      setLoading(false);
    }
  };
  return (
    <div className={styles.report_container}>
      <Popup visible={areaVisible} style={{ height: "40%" }} position="bottom">
        <Picker
          title="选择地区"
          columns={columns}
          onChange={(val: number, selectRow: any, index: number) => {
            setArea(val);
          }}
          onCancel={() => {
            setAreaVisible(false);
          }}
          onConfirm={() => {
            setAreaVisible(false);
          }}
        />
      </Popup>
      <div className={styles.content}>
        <Card style={{ borderRadius: 10 }}>
          <Card.Header>问题描述</Card.Header>
          <Card.Body>
            <Input.TextArea
              placeholder="输入问题描述，详细描述问题情况有助于我们及时解决上报的问哦，不低于5个字。。。。"
              style={{ backgroundColor: "#f3f3f3" }}
              autoSize={{ minHeight: 120, maxHeight: 160 }}
              defaultValue={problemDesc}
              onChange={(val) => {
                setProblemDesc(val);
              }}
            />
          </Card.Body>
        </Card>
        <div
          className={styles.location_container}
          onClick={() => {
            history.push("/locationSearch");
          }}
        >
          <div className={styles.location_title}>事发位置</div>
          <div className={styles.location_text}>
            <div>
              {matterAddress?.addres ? matterAddress?.addres : "无定位"}
            </div>
            <svg
              className="icon"
              aria-hidden="true"
              style={{ width: "22px", height: "22px" }}
            >
              <use xlinkHref="#icon-dingwei"></use>
            </svg>
          </div>
        </div>

        <div
          className={styles.location_container}
          onClick={() => {
            setAreaVisible(true);
          }}
        >
          <div className={styles.location_title}>所属地区</div>
          <div className={styles.location_text}>
            <div>{area ? findName(area) : "请选择"}</div>
            <svg
              className="icon"
              aria-hidden="true"
              style={{ width: "22px", height: "22px" }}
            >
              <use xlinkHref="#icon-dingwei"></use>
            </svg>
          </div>
        </div>

        <Card style={{ borderRadius: 10, marginTop: 16 }}>
          <Card.Header>上传照片</Card.Header>
          <Card.Body>
            <Uploader
              accept="*"
              defaultValue={fileList}
              onChange={(v) => {
                setFileList(v);
              }}
            />
          </Card.Body>
        </Card>

        <div>
          <p>提示说明</p>
          <div>1、问题照片至少两张，一张近景，一张远景。</div>
          <div>
            2、收到您所反映的问题后，我们将马上展开问题处置，问题处置情况可在“我的上报”查看。
          </div>
          <div>3、处置完成后记得对我们的工作做出评价，有惊喜哦。</div>
          <div>
            4、我们收到您所反映的问题后，会马上展开问题核实，您有任何疑问或建议，可拨打我们的值班电话：xxxx。
          </div>
        </div>

        <div style={{ marginTop: 16 }}>
          <Button
            type="primary"
            block
            round
            onClick={handleSubmit}
            loading={loading}
          >
            上报
          </Button>
        </div>
      </div>
    </div>
  );
};

export default Report;
